@@ -355,10 +355,13 @@ mod tests {
     // --------------------------------------------------
     #[test]
     fn sxs_sxs() {
-        let a = MatrixSxS::from([[1., 2., 3.], [4., 5., 6.]]);
-        let b = MatrixSxS::from([[7., 8., 9.], [10., 11., 12.]]);
+        let a = MatrixSxS::<f32, 2, 3>::from([[1., 2., 3.], [4., 5., 6.]]);
+        let b = MatrixSxS::<f32, 2, 3>::from([[7., 8., 9.], [10., 11., 12.]]);
         let c = a / b;
-        let d = MatrixSxS::from([[1. / 7., 2. / 8., 3. / 9.], [4. / 10., 5. / 11., 6. / 12.]]);
+        let d = MatrixSxS::<f32, 2, 3>::from([
+            [1. / 7., 2. / 8., 3. / 9.],
+            [4. / 10., 5. / 11., 6. / 12.],
+        ]);
         assert_eq!(c, d);
     }
     #[test]
